
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include <config-miners.h>

#include "tracker-miners-enum-types.h"
/* enumerations from "tracker-enums.h" */
#include "/build/tracker-miners/src/build/../tracker-miners/src/libtracker-miners-common/tracker-enums.h"
GType
tracker_verbosity_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TRACKER_VERBOSITY_ERRORS, "TRACKER_VERBOSITY_ERRORS", "errors" },
      { TRACKER_VERBOSITY_MINIMAL, "TRACKER_VERBOSITY_MINIMAL", "minimal" },
      { TRACKER_VERBOSITY_DETAILED, "TRACKER_VERBOSITY_DETAILED", "detailed" },
      { TRACKER_VERBOSITY_DEBUG, "TRACKER_VERBOSITY_DEBUG", "debug" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = 
       g_enum_register_static (g_intern_static_string ("TrackerVerbosity"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}
GType
tracker_sched_idle_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TRACKER_SCHED_IDLE_ALWAYS, "TRACKER_SCHED_IDLE_ALWAYS", "always" },
      { TRACKER_SCHED_IDLE_FIRST_INDEX, "TRACKER_SCHED_IDLE_FIRST_INDEX", "first-index" },
      { TRACKER_SCHED_IDLE_NEVER, "TRACKER_SCHED_IDLE_NEVER", "never" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = 
       g_enum_register_static (g_intern_static_string ("TrackerSchedIdle"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}
GType
tracker_serialization_format_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TRACKER_SERIALIZATION_FORMAT_SPARQL, "TRACKER_SERIALIZATION_FORMAT_SPARQL", "sparql" },
      { TRACKER_SERIALIZATION_FORMAT_TURTLE, "TRACKER_SERIALIZATION_FORMAT_TURTLE", "turtle" },
      { TRACKER_SERIALIZATION_FORMAT_JSON, "TRACKER_SERIALIZATION_FORMAT_JSON", "json" },
      { TRACKER_SERIALIZATION_FORMAT_JSON_LD, "TRACKER_SERIALIZATION_FORMAT_JSON_LD", "json-ld" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = 
       g_enum_register_static (g_intern_static_string ("TrackerSerializationFormat"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}


/* Generated data ends here */

